@@ -756,7 +756,8 @@ fill_in_information (GSRWindow *window,
 	}
 	gtk_label_set_text (GTK_LABEL (fp->filename), text);
 	g_free (text);
-
+	g_free (name);
+	
 	/* Size */
 	if (stat (window->priv->working_file, &buf) == 0) {
 		char *human;
@@ -845,6 +846,7 @@ file_properties (BonoboUIComponent *uic,
 	dialog = gtk_dialog_new_with_buttons (title, GTK_WINDOW (window),
 					      GTK_DIALOG_DESTROY_WITH_PARENT,
 					      GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE, NULL);
+	g_free (title);
 	gtk_window_set_resizable (GTK_WINDOW(dialog), FALSE);
 	fp = g_new (struct _file_props, 1);
 	fp->dialog = dialog;
@@ -988,16 +990,22 @@ help_about (BonoboUIComponent *uic,
 	    const char *path)
 {
 	static GtkWidget *about = NULL;
+	GdkPixbuf *pixbuf = NULL;
 	const char *authors[2] = {"Iain Holmes <iain@prettypeople.org>", NULL};
 
 	if (about != NULL) {
 		gdk_window_raise (about->window);
 		gdk_window_show (about->window);
 	} else {
+		pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR "/gnome-grecord.png", NULL);
 		about = gnome_about_new (_("Sound Recorder"), VERSION,
 					 "Copyright \xc2\xa9 2002 Iain Holmes",
 					 _("A sound recorder for GNOME"),
-					 authors, NULL, NULL, NULL);
+					 authors, NULL, NULL, pixbuf);
+
+		if (pixbuf != NULL)
+			gdk_pixbuf_unref (pixbuf);
+
 		g_signal_connect (G_OBJECT (about), "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &about);
 		gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (window));
